@@ -12,7 +12,7 @@ use File::Spec     ();
 use constant NO_CACHE => $ENV{MOJO_ASSETPACK_NO_CACHE} || 0;
 use constant DEBUG    => $ENV{MOJO_ASSETPACK_DEBUG}    || 0;
 
-our $VERSION = '0.48';
+our $VERSION = '0.49';
 
 my $MTIME = time;
 
@@ -125,7 +125,8 @@ sub _assets_from_memory {
       return if $c->res->code;
       return unless $path->[1] and 0 == index "$path", $self->base_url;
       return unless my $asset = $c->asset->_asset($path->[1]);
-      $c->res->headers->last_modified(Mojo::Date->new($MTIME))->content_type($c->app->types->type($asset->url =~ /\.(\w+)$/ ? $1 : 'txt') || 'text/plain');
+      $c->res->headers->last_modified(Mojo::Date->new($MTIME))
+        ->content_type($c->app->types->type($asset->url =~ /\.(\w+)$/ ? $1 : 'txt') || 'text/plain');
       $c->reply->asset($asset);
     }
   );
@@ -182,6 +183,9 @@ sub _find {
   my $self   = shift;
   my @path   = @_;
 
+  # avoid matching .swp files
+  $needle = qr{^$needle$} unless ref $needle;
+
   for my $path (map { File::Spec->catdir($_, @path) } @{$self->_app->static->paths}) {
     opendir my $DH, $path or next;
     for (readdir $DH) {
@@ -265,8 +269,10 @@ sub _process {
       $asset->add_chunk($content);
       1;
     } or do {
+      my $e = $@;
+      warn "[ASSETPACK] process(@{[$source->url]}) FAIL $e\n" if DEBUG;
       $asset->url(File::Spec->catfile($self->out_dir, "$name-$checksum[0].err.$ext"));
-      $asset->add_chunk($self->_make_error_asset($moniker, $source->basename, $@));
+      $asset->add_chunk($self->_make_error_asset($moniker, $source->basename, $e || 'Unknown error'));
       last;
     };
   }
@@ -302,7 +308,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-0.48
+0.49
 
 =head1 SYNOPSIS
 
